// #pragma comment(linker, "/stack:200000000")
// #pragma GCC optimize("Ofast,no-stack-protector")
// #pragma GCC target("sse,sse2,sse3,ssse3,sse4,popcnt,abm,mmx,avx,avx2,tune=native")
// #pragma GCC optimize("unroll-loops")

#include <stdio.h>
#include <bits/stdc++.h>

#ifdef PERVEEVM_LOCAL
    #define debug(x) std::cerr << (#x) << ":\t" << (x) << std::endl
#else
    #define debug(x) 238;
#endif

#define fastIO std::ios_base::sync_with_stdio(false); std::cin.tie(0); std::cout.tie(0)
#define NAME "File"

using ll = long long;
using ld = long double;

#ifdef PERVEEVM_LOCAL
    std::mt19937 rnd(238);
#else
    std::mt19937 rnd(std::chrono::high_resolution_clock::now().time_since_epoch().count());
#endif

template<typename T>
bool smin(T& a, const T& b) {
    if (b < a) {
        a = b;
        return true;
    }
    return false;
}

template<typename T>
bool smax(T& a, const T& b) {
    if (a < b) {
        a = b;
        return true;
    }
    return false;
}

const double PI = atan2(0.0, -1.0);
const int INF = 0x3f3f3f3f;
const ll LINF = (ll)2e18;
const int N = 100100;

int n;
std::vector<std::pair<int, int>> g[N];
int d[N], rd[N];
int color[N];
std::vector<int> needEdges;
int mnL[N], mnR[N];
std::pair<int, int> allEdges[2 * N];
bool isGoodEdge[2 * N];

void bfs(int s) {
	std::queue<int> q;
	q.push(s);
	memset(d, INF, sizeof(d));
	d[s] = 0;

	while (!q.empty()) {
		int v = q.front();
		q.pop();

		for (auto[to, id] : g[v]) {
			if (d[to] == INF) {
				d[to] = d[v] + 1;
				q.push(to);
			}
		}
	}
}

void revBfs(int s) {
	std::queue<int> q;
	q.push(s);
	memset(rd, INF, sizeof(rd));
	rd[s] = 0;

	while (!q.empty()) {
		int v = q.front();
		q.pop();
		for (auto[to, id] : g[v]) {
			if (rd[to] == INF) {
				rd[to] = rd[v] + 1;
				q.push(to);
			}
		}
	}
}

std::vector<int> restoreLeftPath(int v) {
	std::vector<int> ans;
	while (v != 0) {
		// debug(v);
		bool found = false;
		ans.push_back(v);
		for (auto[to, id] : g[v]) {
			if (d[to] == d[v] - 1 && std::min(color[id], mnL[to]) == mnL[v]) {
				v = to;
				found = true;
				break;
			}
		}

		if (!found) {
			throw;
		}
	}
	ans.push_back(0);
	return ans;
}

std::vector<int> restoreRightPath(int v) {
	std::vector<int> ans;
	while (v != n - 1) {
		ans.push_back(v);
		bool found = false;
		for (auto[to, id] : g[v]) {
			if (rd[to] == rd[v] - 1 && std::min(color[id], mnR[to]) == mnR[v]) {
				v = to;
				found = true;
				break;
			}
		}
		if (!found) {
			throw;
		}
	}
	ans.push_back(n - 1);
	return ans;
}

void run() {
	int m;
	scanf("%d%d", &n, &m);

	for (int i = 0; i < m; ++i) {
		int from, to, c;
		scanf("%d%d%d", &from, &to, &c);

		allEdges[i] = std::make_pair(from - 1, to - 1);
		g[from - 1].push_back(std::make_pair(to - 1, i));
		g[to - 1].push_back(std::make_pair(from - 1, i));
		color[i] = c;
	}

	bfs(0);
	revBfs(n - 1);

	for (int from = 0; from < n; ++from) {
		for (auto[to, id] : g[from]) {
			if (isGoodEdge[id]) {
				continue;
			}
			if (d[from] + 1 + rd[to] == d[n - 1]) {
				isGoodEdge[id] = true;
				needEdges.push_back(id);
			} else if (d[to] + 1 + rd[from] == d[n - 1]) {
				isGoodEdge[id] = true;
				needEdges.push_back(id);
			}
		}
	}

	// for (auto i : needEdges) {
	// 	std::cout << i + 1 << ' ';
	// }
	// std::cout << std::endl;

	std::vector<std::pair<int, int>> order;
	for (int i = 0; i < n; ++i) {
		if (d[i] == d[n - 1] && i != n - 1) {
			continue;
		}
		order.push_back(std::make_pair(d[i], i));
	}

	std::sort(order.begin(), order.end());

	memset(mnL, INF, sizeof(mnL));
	memset(mnR, INF, sizeof(mnR));

	for (auto[dist, v] : order) {
		if (d[v] == INF) {
			continue;
		}
		for (auto[to, id] : g[v]) {
			if (d[to] == d[v] + 1) {
				smin(mnL[to], mnL[v]);
				smin(mnL[to], color[id]);
			}
		}
	}

	std::reverse(order.begin(), order.end());

	for (auto[dist, v] : order) {
		if (rd[v] == INF) {
			continue;
		}
		for (auto[to, id] : g[v]) {
			if (d[to] == d[v] - 1) {
				smin(mnR[to], mnR[v]);
				smin(mnR[to], color[id]);
			}
		}
	}

	std::vector<std::pair<int, int>> edges;
	for (auto i : needEdges) {
		edges.push_back(std::make_pair(color[i], i));
	}

	std::sort(edges.begin(), edges.end());

	// for (int i = 0; i < n; ++i) {
	// 	std::cout << mnL[i] << ' ' << mnR[i] << std::endl;
	// }

	int ans = -1;
	int bestEdgeId = -1;
	for (auto[c, id] : edges) {
		int from = allEdges[id].first;
		int to = allEdges[id].second;

		if (d[from] > d[to]) {
			std::swap(from, to);
		}

		int minOnPath = c;
		if (from != 0) {
			smin(minOnPath, mnL[from]);
		}
		if (to != 0) {
			smin(minOnPath, mnR[to]);
		}

		if (smax(ans, c - minOnPath)) {
			bestEdgeId = id;
			// std::cout << ans << ' ' << from << ' ' << to << ' ' << c << std::endl;
		}
	}

	// printf("%d\n", ans);
	// debug(bestEdgeId);
	int from = allEdges[bestEdgeId].first;
	int to = allEdges[bestEdgeId].second;
	if (d[from] > d[to]) {
		std::swap(from, to);
	}

	auto lPath = restoreLeftPath(from);
	auto rPath = restoreRightPath(to);

	printf("%d\n", (int)lPath.size() + (int)rPath.size() - 1);
	std::reverse(lPath.begin(), lPath.end());

	for (auto i : lPath) {
		printf("%d ", i + 1);
	}
	for (auto i : rPath) {
		printf("%d ", i + 1);
	}
	printf("\n");
}

int main(void) {
    // freopen(NAME".in", "r", stdin);
    // freopen(NAME".out", "w", stdout);

    auto start = std::chrono::high_resolution_clock::now();
    run();
    auto end = std::chrono::high_resolution_clock::now();

    #ifdef PERVEEVM_LOCAL
        std::cerr << "Execution time: "
                  << std::chrono::duration_cast<std::chrono::milliseconds>(end - start).count()
                  << " ms" << std::endl;
    #endif

    return 0;
}
