#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ull = unsigned long long;

mt19937 mt(736);


void bfs(const vector<vector<pair<int, int>>> &gr, vector<int> &dist, int v)
{
	queue<pair<int, int>> q;
	q.emplace(v, 0);

	while (!q.empty())
	{
		auto[v, d] = q.front();
		q.pop();

		if (dist[v] != -1)
			continue;

		dist[v] = d;

		for (auto[u, w]: gr[v])
			q.emplace(u, d + 1);
	}
}


class slv
{
	const vector<vector<pair<int, int>>> &gr;
	vector<pair<int, int>> par, dist;

public:
	slv(const vector<vector<pair<int, int>>> &gr, int st) :
			gr(gr), par(gr.size(), {-1, -1}),
			dist(gr.size(), {numeric_limits<int>::max() / 2, numeric_limits<int>::lowest() / 2})
	{
		vector<int> ds(gr.size(), -1);

		bfs(gr, ds, st);

		vector<int> ord(gr.size());
		iota(ord.begin(), ord.end(), 0);

		sort(ord.begin(), ord.end(), [&](int a, int b)
		{
			return ds[a] < ds[b];
		});

		for (auto it: ord)
			for (auto[prev, c]: gr[it])
				if (ds[prev] + 1 == ds[it])
				{
					if (auto q = max(dist[prev].second, c); q > dist[it].second)
					{
						dist[it].second = q;
						par[it].second = prev;
					}

					if (auto q = min(dist[prev].first, c); q < dist[it].first)
					{
						dist[it].first = q;
						par[it].first = prev;
					}
				}
	}


	const pair<int, int> &operator[](int v) const
	{
		return dist[v];
	}


	template<int q, class It>
	void get_path(int v, It out) const
	{
		*out++ = v;

		while (get<q>(par[v]) != -1)
		{
			v = get<q>(par[v]);
			*out++ = v;
		}
	}
};


void solve(istream &cin = std::cin, ostream &cout = std::cout)
{
	int n, m;

	cin >> n >> m;

	vector<vector<pair<int, int>>> gr(n);

	for (int j = 0; j < m; j++)
	{
		int a, b, w;

		cin >> a >> b >> w;
		a--;
		b--;

		gr[a].emplace_back(b, w);
		gr[b].emplace_back(a, w);
	}

	vector<int> ds(n, -1), dt(n, -1);

	bfs(gr, ds, 0);
	bfs(gr, dt, n - 1);

	slv s{gr, 0}, t(gr, n - 1);

	int best = -1, v = 0;

	for (int i = 0; i < gr.size(); i++)
		if (ds[v] + dt[v] == dt[0])
		{
			auto val = max(s[i].second - t[i].first, t[i].second - s[i].first);

			if (val > best)
			{
				best = val;
				v = i;
			}
		}

	cerr << best << ' ' << v << endl;

	vector<int> le, ri;

	if (s[v].second - t[v].first > t[v].second - s[v].first)
	{
		s.get_path<1>(v, back_inserter(le));
		t.get_path<0>(v, back_inserter(ri));
	}
	else
	{
		s.get_path<0>(v, back_inserter(le));
		t.get_path<1>(v, back_inserter(ri));
	}

	for (auto &it: le)
		it++;
	for (auto &it: ri)
		it++;

	cout << le.size() + ri.size() - 2 << endl;

	copy(le.rbegin(), le.rend(), ostream_iterator<int>(cout, " "));
	copy(ri.begin() + 1, ri.end(), ostream_iterator<int>(cout, " "));
	cout << endl;
}


int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

	cout << fixed;

#ifdef LOCAL
	auto st = clock();

	ifstream fin("../input.txt");

	do
	{
		solve(fin);

		cout << "===" << endl;

		string str;
		while (getline(fin, str) && str != string(max(1, (int) str.size()), '='));
	} while (fin);

	cout << setprecision(6) << "clock: " << double(clock() - st) / CLOCKS_PER_SEC << endl;
#else
	solve();
#endif

	return 0;
}
