﻿#include <algorithm>
#include <cmath>
#include <iostream>
#include <map>
#include <vector>
#include <numeric>
#include <queue>

using namespace std;

const int INF = 1e9 + 100;

struct edge {
	int w, color;
};

int main() {
	ios_base::sync_with_stdio(0); cin.tie(0); cout.tie(0);
	int n, m;
	cin >> n >> m;
	vector<vector<edge>> g(n);
	for (int i = 0; i < m; i++) {
		int u, v, c;
		cin >> u >> v >> c;
		u--; v--;
		g[u].push_back({v, c});
		g[v].push_back({u, c});
	}

	vector<int> dist(n, INF);
	dist[0] = 0;
	vector<bool> used(n);
	queue<int> q;

	used[0] = true;
	q.push(0);

	vector<int> max_on_route(n, -INF);
	vector<int> min_on_route(n, INF);
	vector<int> max_diff(n);
	vector<int> dp_parent(n);
	max_diff[0] = 0;
	dp_parent[0] = -1;

	while (!q.empty()) {
		int v = q.front();
		q.pop();
		for (const auto& [w, color] : g[v]) {
			if (used[w]) {
				continue;
			}
			used[w] = true;
			dist[w] = dist[v] + 1;
			q.push(w);
		}

		if (v == 0) {
			continue;
		}

		max_diff[v] = -INF;

		for (const auto& [parent, color] : g[v]) {
			if (dist[parent] != dist[v] - 1) {
				continue;
			}
			max_on_route[v] = max({max_on_route[v], max_on_route[parent], color});
			min_on_route[v] = min({min_on_route[v], min_on_route[parent], color});

			
			int new_max_diff = max({0, max_diff[parent], color - min_on_route[parent], max_on_route[parent] - color});
			if (new_max_diff > max_diff[v]) {
				max_diff[v] = new_max_diff;
				dp_parent[v] = parent;
			}
		}
	}

	int cur_v = n - 1;
	vector<int> path;
	while (cur_v != -1) {
		path.push_back(cur_v);
		cur_v = dp_parent[cur_v];
	}
	reverse(path.begin(), path.end());
	cout << path.size() - 1 << "\n";
	for (int v : path) {
		cout << v + 1 << " ";
	}
}
