﻿#include <cmath>
#include <iostream>
#include <set>
#include <vector>
#include <string>
#include <map>

using namespace std;

struct command {
    string lhs;
    int rhs;

    bool operator==(const command& other) const {
        return lhs == other.lhs && rhs == other.rhs;
    }
};

command read_command() {
    string s;
    cin >> s;
    string lhs, rhs;
    bool had_equals_sign = false;
    for (char c : s) {
        if (c == '=') {
            had_equals_sign = true;
        } else if (!had_equals_sign) {
            lhs += c;
        } else {
            rhs += c;
        }
    }
    int rhs_i = stoi(rhs);
    return {lhs, rhs_i};
}

struct program {
    int index;
    vector<command> commands;
};

int main() {
    ios_base::sync_with_stdio(0); cin.tie(0); cout.tie(0);

    int t;
    cin >> t;
    vector<program*> programs;
    for (int i = 0; i < t; i++) {
        int len;
        cin >> len;
        program* p = new program;
        p->index = i;
        p->commands.reserve(len);
        for (int i = 0; i < len; i++) {
            p->commands.push_back(read_command());
        }
        programs.push_back(p);
    }

    int k;
    cin >> k;
    map<string, int> requirements;

    for (int i = 0; i < k; i++) {
        string s;
        int val;
        cin >> s >> val;
        requirements[s] = val;
    }

    vector<int> program_order;
    set<program*> good_programs;
    for (auto p : programs) {
        const auto& last_command = p->commands.back();
        if (requirements[last_command.lhs] == last_command.rhs) {
            good_programs.insert(p);
        }
    }

    while (!requirements.empty()) {
        if (good_programs.empty()) {
            cout << "No\n";
            return 0;
        }
        program* good_program = *good_programs.begin();
        good_programs.erase(good_program);

        program_order.push_back(good_program->index);
        requirements.erase(good_program->commands.back().lhs);

        good_program->commands.pop_back();

        if (good_programs.empty()) {
            for (auto p : programs) {
                while (!p->commands.empty()) {
                    const auto& last_command = p->commands.back();
                    if (requirements.find(last_command.lhs) == requirements.end()) {
                        program_order.push_back(p->index);
                        p->commands.pop_back();
                    } else {
                        break;
                    }
                }
            }

            for (auto p : programs) {
                if (p->commands.empty()) {
                    continue;
                }
                const auto& last_command = p->commands.back();
                if (requirements[last_command.lhs] == last_command.rhs) {
                    good_programs.insert(p);
                }
            }
        }
    }

    reverse(program_order.begin(), program_order.end());
    cout << "Yes\n";
    for (int p_index : program_order) {
        cout << p_index + 1 << " ";
    }
}