#include <iostream>
#include <vector>
#include <string>
#include <algorithm>
#include <unordered_map>
#include <unordered_set>
#include <map>
#include <set>

using namespace std;
using ll = long long;

int n, m;

struct Timestamp {
    int time;
    int id;

    int next() const {
        return m - time % m;
    }

    int day(int delta = 0) const {
        return (time + delta) / m;
    }
};

struct Segment {
    int begin;
    int len;

    bool operator<(const Segment& that) const {
        return begin < that.begin;
    }

    bool contains(int val) const {
        return val >= begin && val < begin + len;
    }

    int end() const {
        return begin + len;
    }
};

void solve() {
    cin >> n >> m;
    vector<Timestamp> ts(n);
    for (int i = 0; i < n; ++i) {
        cin >> ts[i].time;
        ts[i].id = i;
    }

    unordered_map<int, int> count;

    set<Segment> segments;
    map<int, int> lengths;

    auto getSegment = [&](int day) {
        auto it = segments.lower_bound(Segment { day, 0 });
        if (it != segments.end()) {
            if (it->contains(day)) return it;
        }
        if (it != segments.begin()) {
            --it;
            if (it->contains(day)) return it;
        }
        return segments.end();
    };

    auto getSegmentVal = [&](int day) {
        auto it = getSegment(day);
        if (it == segments.end()) {
            return Segment { 0, 0 };
        } else {
            return *it;
        }
    };

    auto removeSegment = [&](int day) {
        auto seg = getSegment(day);
        if (seg == segments.end()) return;
        if (--lengths[seg->len] <= 0) {
            lengths.erase(seg->len);
        }
        segments.erase(seg);
    };
    
    auto addSegment = [&](Segment seg) {
        if (seg.len > 0) {
            lengths[seg.len]++;
            segments.insert(seg);
        }
    };

    auto addDay = [&](int day) {
        if (++count[day] == 1) {
            auto prev = getSegmentVal(day - 1);
            auto next = getSegmentVal(day + 1);
            int begin = day - prev.len;
            int end = day + next.len + 1;
            removeSegment(day - 1);
            removeSegment(day + 1);
            addSegment(Segment { begin, end - begin });
        }
    };

    auto removeDay = [&](int day) {
        if (--count[day] == 0) {
            auto seg = getSegmentVal(day);
            if (seg.len > 0) {
                removeSegment(day);
                addSegment(Segment { seg.begin, day - seg.begin });
                addSegment(Segment { day + 1, seg.end() - (day + 1) });
            }
        }
    };

    auto longest = [&]() {
        auto it = lengths.end();
        --it;
        return it->first;
    };

    for (const auto& t : ts) {
        addDay(t.day());
    }

    int best = longest();
    int bestTz = 0;

    sort(ts.begin(), ts.end(), [&](const auto& lhs, const auto& rhs) {
        return lhs.next() < rhs.next();
    });

    for (int i = 0; i < n; ++i) {
        if (ts[i].time % m == 0) continue;

        int tz = ts[i].next();
        removeDay(ts[i].day());
        addDay(ts[i].day(tz));
        if (longest() > best) {
            best = longest();
            bestTz = tz;
        }
    }

    cout << best << " " << bestTz << "\n";
}

int main() {
    cin.tie(nullptr);
    ios::sync_with_stdio(false);

    int t;
    cin >> t;
    for (int i = 0; i < t; ++i) {
        solve();
    }
    return 0;
}
