#include <bits/stdc++.h>
#define int long long
using namespace std;
typedef long double ld;
typedef complex<double> cld;

const int inf = 1e18;
const ld eps = 1e-9;
const ld pi = atan2(0, -1);
const int mod = 1e9+7;

/// Code  part ///

struct Edge {
    int u, v, c;
    Edge() {u = v = c = 0;}
    Edge(int u, int v, int c): u(u), v(v), c(c) {}
};

struct Solver {
    vector<vector<Edge>> g;
    vector<vector<int>> d_vertexes;
    vector<int> d;
    int n, m;

    vector<int> prev_min, prev_max;
    vector<int> prev_min_v, prev_max_v;

    vector<int> next_min, next_max;
    vector<int> next_min_v, next_max_v;

    Solver() {
        cin >> n >> m;
        g.assign(n, vector<Edge>(0, {0, 0, 0}));
        d.assign(n, -1);
        d_vertexes.assign(n, vector<int>(0, 0));

        for(int i = 0; i < m; ++i) {
            int u, v, c;
            cin >> u >> v >> c;
            u--; v--;
            g[u].push_back({u, v, c});
            g[v].push_back({v, u, c});
        }
    }

    void bfs_d() {
        queue<int> q;
        q.push(0);
        d[0] = 0;

        while(!q.empty()) {
            int u = q.front();
            q.pop();

            for(Edge e: g[u]) {
                int v = e.v;
                if(d[v] == -1) {
                    d[v] = d[u]+1;
                    q.push(v);
                }
            }
        }
    }

    vector<int> get_route(int v, int dir) {
        if(dir == 1) {
            vector<int> route;
            int u = v;
            while(u != 0) {
                u = prev_min_v[u];
                route.push_back(u);
            }
            reverse(route.begin(), route.end());

            route.push_back(v);
            u = v;
            while(u != n-1) {
                u = next_max_v[u];
                route.push_back(u);
            }
            return route;
        }

        else {
            vector<int> route;
            int u = v;
            while(u != 0) {
                u = prev_max_v[u];
                route.push_back(u);
            }
            reverse(route.begin(), route.end());

            route.push_back(v);
            u = v;
            while(u != n-1) {
                u = next_min_v[u];
                route.push_back(u);
            }
            return route;
        }
    }
    
    void solve() {
        bfs_d();
        if(d[n-1] == 1) {
            cout << "1\n1 " << n << "\n";
            return;
        }
        for(int i = 0; i < n; ++i) 
            if(d[i] < d[n-1]) d_vertexes[d[i]].push_back(i);
        d_vertexes[d[n-1]].push_back(n-1);
    
        // Calculate prev
        prev_min.assign(n, inf);
        prev_max.assign(n, -inf);
        prev_min_v.assign(n, -1);
        prev_max_v.assign(n, -1);

        for(int cur_d = 1; cur_d <= d[n-1]; ++cur_d) {
            for(int u : d_vertexes[cur_d]) {
                for(Edge e : g[u]) {
                    int v = e.v, c = e.c;
                    if(d[v] >= d[u]) continue;

                    c = min(e.c, prev_min[v]);
                    if(c < prev_min[u]) {
                        prev_min[u] = c;
                        prev_min_v[u] = v;
                    }

                    c = max(e.c, prev_max[v]);
                    if(c > prev_max[u]) {
                        prev_max[u] = c;
                        prev_max_v[u] = v;
                    }
                }
            }
        }

        // Calculate next
        next_min.assign(n, inf);
        next_max.assign(n, -inf);
        next_min_v.assign(n, -1);
        next_max_v.assign(n, -1);

        for(int cur_d = d[n-1]-1; cur_d >= 0; --cur_d) {
            for(int u : d_vertexes[cur_d]) {
                for(Edge e : g[u]) {
                    int v = e.v, c = e.c;
                    if(d[v] <= d[u]) continue;
                    if((d[v] >= d[n-1]) && (v != n-1)) continue;

                    c = min(e.c, next_min[v]);
                    if(c < next_min[u]) {
                        next_min[u] = c;
                        next_min_v[u] = v;
                    }

                    c = max(e.c, next_max[v]);
                    if(c > next_max[u]) {
                        next_max[u] = c;
                        next_max_v[u] = v;
                    }
                }
            }
        }

        int ans = -inf;
        int v_ans = -1;
        int dir = -1;
        for(int u = 0; u < n; ++u) {
            if(d[u] >= d[n-1]) continue;
            if(next_max[u]-prev_min[u] > ans) {
                ans = next_max[u]-prev_min[u];
                v_ans = u;
                dir = 1;
            }

            if(prev_max[u]-next_min[u] > ans) {
                ans = prev_max[u] - next_min[u];
                v_ans = u;
                dir = 2;
            }
        }

        vector<int> route = get_route(v_ans, dir);
        cout << route.size()-1 << "\n";
        for(int i : route)
            cout << i+1 << " ";
        cout << "\n";
    }
};

/// Code part ///
int file_io = 0, debug = 0;

int32_t main() {
    // file_io = 1;

    if(file_io) freopen("inp.txt", "r", stdin);
    ios_base::sync_with_stdio(0);
    cin.tie(0); cout.tie(0);

    int tests = (debug ? 1000 : 1);
    if(file_io) cin >> tests;

    for(int test = 0; test < tests; ++test) {
        if(!debug) {
            /// Main part ///

            Solver solver;
            solver.solve();

            /// Main part ///
        } else {}
    }

    return 0;
}

/**

*/
