#include <bits/stdc++.h>
using namespace std;

const int INF = 2e9;

struct Edge {
    int from;
    int to;
    int value;
};

struct Info {
    int dist = INF;
    int value = INF;
    int prev = -1;
};

template<typename T>
bool get_min(T &lhs, const T &rhs) {
    if (lhs > rhs) {
        lhs = rhs;
        return true;
    }
    return false;
}
template<typename T>
bool get_max(T &lhs, const T &rhs) {
    if (lhs < rhs) {
        lhs = rhs;
        return true;
    }
    return false;
}

int n;
int m;
vector<vector<Edge>> graph;
vector<Info> bfs(int source) {
    vector<Info> result(n + 1);
    result[source] = Info{0, INF, -1};
    vector<bool> used(n + 1);
    used[source] = true;
    queue<int> order;
    order.push(source);
    while (!order.empty()) {
        int v = order.front();
        order.pop();
        for (Edge edge : graph[v]) {
            int u = edge.to;
            if (used[u]) {
                if (result[u].dist == result[v].dist + 1) {
                    if (get_min(result[u].value, edge.value)) {
                        result[u].prev = v;
                    }
                }
                continue;
            }
            used[u] = true;
            result[u] = Info{result[v].dist + 1, min(edge.value, result[v].value), v};
            order.push(u);
        }
    }
    return result;
}

vector<Info> info_from_1;
vector<Info> info_from_n;

bool is_vertex_correct(int vertex) {
    return info_from_1[vertex].dist + info_from_n[vertex].dist == info_from_1[n].dist;
}

void restore_path(int source, vector<int> &path, const vector<Info> &info) {
    int current = source;
    while (current != -1) {
        path.push_back(current);
        current = info[current].prev;
    }
}

void run() {
    cin >> n >> m;
    graph.resize(n + 1);
    for (int i = 0; i < m; i++) {
        int from;
        int to;
        int value;
        cin >> from >> to >> value;
        graph[from].push_back(Edge{from, to, value});
        graph[to].push_back(Edge{to, from, value});
    }

    info_from_1 = bfs(1);
    info_from_n = bfs(n);

    Edge best;
    int answer = -1;
    for (auto &i : graph) {
        for (Edge edge : i) {
            if (info_from_1[edge.to].dist != info_from_1[edge.from].dist + 1) {
                continue;
            }
            if (is_vertex_correct(edge.from) && is_vertex_correct(edge.to)) {
                int min_from_left = info_from_1[edge.from].value;
                if (edge.from == 1) {
                    min_from_left = edge.value;
                }
                int min_from_right = info_from_n[edge.to].value;
                if (edge.to == n) {
                    min_from_right = edge.value;
                }
                auto tmp = edge.value - min(min_from_left, min_from_right);
                if (get_max(answer, tmp)) {
                    best = edge;
                }
            }
        }
    }
    assert(answer != -1);
    vector<int> path;
    restore_path(best.from, path, info_from_1);
    reverse(path.begin(), path.end());
    restore_path(best.to, path, info_from_n);
    assert(path.size() - 1 == info_from_1[n].dist);
    cout << path.size() - 1 << '\n';
    for (int vertex : path) {
        cout << vertex << " ";
    }
}

signed main() {
#ifdef LOCAL
    freopen("data", "r", stdin);
#endif
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    cout.setf(ios::fixed);
    cout.precision(16);
    run();
    return 0;
}