﻿using System;
using System.Collections.Generic;

namespace olp
{
    public class Simplex
    {
        double[,] table;
        int m, n;

        List<int> basis;
        public Simplex(double[,] source)
        {
            m = source.GetLength(0);
            n = source.GetLength(1);
            table = new double[m, n + m - 1];
            basis = new List<int>();

            for (int i = 0; i < m; i++)
            {
                for (int j = 0; j < table.GetLength(1); j++)
                {
                    if (j < n)
                        table[i, j] = source[i, j];
                    else
                        table[i, j] = 0;
                }

                if ((n + i) < table.GetLength(1))
                {
                    table[i, n + i] = 1;
                    basis.Add(n + i);
                }
            }

            n = table.GetLength(1);
        }
        public double[,] Calculate(double[] result)
        {
            int mainCol, mainRow;

            while (!IsItEnd())
            {
                mainCol = findMainCol();
                mainRow = findMainRow(mainCol);
                basis[mainRow] = mainCol;

                double[,] new_table = new double[m, n];

                for (int j = 0; j < n; j++)
                    new_table[mainRow, j] = table[mainRow, j] / table[mainRow, mainCol];

                for (int i = 0; i < m; i++)
                {
                    if (i == mainRow)
                        continue;

                    for (int j = 0; j < n; j++)
                        new_table[i, j] = table[i, j] - table[i, mainCol] * new_table[mainRow, j];
                }
                table = new_table;
            }

            for (int i = 0; i < result.Length; i++)
            {
                int k = basis.IndexOf(i + 1);
                if (k != -1)
                    result[i] = table[k, 0];
                else
                    result[i] = 0;
            }

            return table;
        }

        private bool IsItEnd()
        {
            bool flag = true;

            for (int j = 1; j < n; j++)
            {
                if (table[m - 1, j] < 0)
                {
                    flag = false;
                    break;
                }
            }

            return flag;
        }

        private int findMainCol()
        {
            int mainCol = 1;

            for (int j = 2; j < n; j++)
                if (table[m - 1, j] < table[m - 1, mainCol])
                    mainCol = j;

            return mainCol;
        }

        private int findMainRow(int mainCol)
        {
            int mainRow = 0;

            for (int i = 0; i < m - 1; i++)
                if (table[i, mainCol] > 0)
                {
                    mainRow = i;
                    break;
                }

            for (int i = mainRow + 1; i < m - 1; i++)
                if ((table[i, mainCol] > 0) && ((table[i, 0] / table[i, mainCol]) < (table[mainRow, 0] / table[mainRow, mainCol])))
                    mainRow = i;

            return mainRow;
        }


    }

    class Program
    {
        static void Main(string[] args)
        {
            long n = Convert.ToInt64(Console.ReadLine());
            long m = Convert.ToInt64(Console.ReadLine());
            long c = Convert.ToInt64(Console.ReadLine());
            
            double[,] table = { {n, c, m },
                                { 0, -c, -m} };

            double[] result = new double[2];
            double[,] table_result;
            Simplex S = new Simplex(table);
            table_result = S.Calculate(result);

            long[] arr = new long[10000];
            long[] C = new long[10000];
            long[] M = new long[10000];
            int cnt = 0;

            C[cnt] = Convert.ToInt64(result[0]);
            M[cnt] = Convert.ToInt64(result[1]);
            // arr[cnt] = Math.Abs(n - c * C[cnt] - m * M[cnt]);

            long min = Math.Abs(n - c * C[cnt] - m * M[cnt]);
            long minC = C[cnt];
            long minM = M[cnt];

            long d = 1000;

            long lC = (C[cnt] - d > 0) ? C[cnt] - d : 0;
            long lM = (M[cnt] - d > 0) ? M[cnt] - d : 0;

            for (long i = lC; i< C[cnt] +d; i++)
            {
                for (long j = lM; j < M[cnt] + d; j++)
                {
                    long res = Math.Abs(n - c * i - m * j);
                    if (res < min)
                    {
                        min = res;
                        minC = i;
                        minM = j;
                    }
                }
            }

            Console.WriteLine(minM + " " + minC);
        }
    }
}
