#include <iostream>
#include <map>
#include <cmath>
#include <vector>
#include <algorithm>
#include <queue>

using namespace std;

struct Node {
    Node* parent;
    int matches;
    Node* children[26];

    Node(Node *parent) {
        this->parent = parent;
        matches = 0;
        for (int i = 0; i < 26; i++)
            children[i] = nullptr;
    }
};


class Compare {
public:
    bool operator() (Node* a, Node* b) {
        return a->matches < b->matches;
    }
};



void add_word(Node* node, const string &word) {
    for (int i = 0; i < word.size(); i++) {
        int c = word[i] - 'a';
        node->matches++;
        if (node->children[c] == nullptr) {
            Node* next = new Node(node);
            node->children[c] = next;
        }
        node = node->children[c];
    }
    node->matches++;
}

void build_max_prefs(Node* node, priority_queue<Node*, vector<Node*>, Compare> &heap, int k) {
    if (node->matches <= k) {
        heap.push(node);
        return;
    }

    for (int i = 0; i < 26; i++) {
        if (node->children[i] != nullptr) {
            build_max_prefs(node->children[i], heap, k);
        }
    }
}

Node* update_prefs(Node *dropped, int k) {
    int dec = dropped->matches;
    Node *node = dropped;
    Node *next;

    while (node != nullptr) {
        node->matches -= dec;
        if (node->matches <= k)
            next = node;

        node = node->parent;
    }

    return next;
}


int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    int n, k;
    cin >> n >> k;
    vector<string> words(n);
    for (int i = 0; i < n; i++) {
        cin >> words[i];
    }

    Node *root = new Node(nullptr);
    priority_queue<Node*, vector<Node*>, Compare> heap;

    for (int i = 0; i < n; i++)
        add_word(root, words[i]);

    build_max_prefs(root, heap, k);

    int iters = 0;
    Node *best;
    do {
        best = heap.top();
        heap.pop();

        Node* next = update_prefs(best, k);
        heap.push(next);

        iters++;
    } while (best != root);

    cout << iters << endl;
    return 0;
}