#include <iostream>
#include <vector>
#include <algorithm>
#include <unordered_set>
#include <queue>
#include <tuple>
#include <exception>
#include <sstream>
#include <iomanip>
#include <memory>
#include <set>
#include <ctime>
#include <cmath>

constexpr int alsize = 'z' - 'a' + 1;

struct Node {
    Node *parent;
    Node *children[alsize];
    int size;
    bool isend = false;

    explicit Node(Node *parent) {
        this->parent = parent;
        for (auto &i: children) {
            i = nullptr;
        }
        size = 0;
    }

    Node *childOf(char c) {
        return children[c - 'a'];
    }

    Node *nonnullChildOf(char c) {
        int idx = c - 'a';

        if (children[idx] != nullptr) {
            return children[idx];
        }

        return children[idx] = new Node(this);
    }

    void addChild(char c, Node *ch) {
        children[c - 'a'] = ch;
    }
};

Node *root = new Node(nullptr);

void addWord(const std::string &word) {
    Node *curr = root;

    for (auto &c: word) {
        curr = curr->nonnullChildOf(c);
    }

    curr->isend = true;
}

int fillSizes(Node *curr) {
    curr->size = curr->isend ? 1 : 0;

    for (auto &i: curr->children) {
        if (i != nullptr) {
            curr->size += fillSizes(i);
        }
    }

    return curr->size;
}

void fillSizes() {
    fillSizes(root);
}

Node *maxNonGreater(Node *curr, int k) {
    if (curr->size <= k) {
        return curr;
    }

    auto max = -1;
    Node *ans = nullptr;

    for (auto &i: curr->children) {
        if (i != nullptr) {
            auto l = maxNonGreater(i, k);

            if (l->size > max) {
                max = l->size;
                ans = l;
            }
        }
    }

    return ans;
}


void remove(Node *node) {
    if (node->parent == nullptr) {
        node->size = 0;
        return;
    }

    for (auto &i: node->parent->children) {
        if (i == node) {
            i = nullptr;
            break;
        }
    }

    int deleted = node->size;

    while (node->parent != nullptr) {
        node->parent->size -= deleted;
        node = node->parent;
    }
}

std::string stringOf(Node *node) {
    std::string result;

    while (node->parent != nullptr) {
        for (int i = 0; i < alsize; ++i) {
            if (node->parent->children[i] == node) {
                result += char('a' + i);
                break;
            }
        }

        node = node->parent;
    }

    std::reverse(result.begin(), result.end());

    return result;
}

int main() {
    std::ios_base::sync_with_stdio(false);

    int n, k;

    std::cin >> n >> k;

    for (int i = 0; i < n; ++i) {
        std::string word;
        std::cin >> word;

        addWord(word);
    }

    fillSizes();

    int ans = 0;

    while (root->size > 0) {
        Node *maxx = maxNonGreater(root, k);

//        std::cout << stringOf(maxx) << "*" << std::endl;

        remove(maxx);

        ans++;
    }

    std::cout << ans << std::endl;

    return 0;
}
